@@ -11,7 +11,8 @@ describe 'ovn::controller' do
       :bridge_interface_mappings => ['br-1:eth1'],
       :hostname                  => 'server1.example.com',
       :enable_hw_offload         => false,
-      :mac_table_size            => 20000
+      :mac_table_size            => 20000,
+      :ovn_remote_probe_interval => 30000,
     }
   end
 
@@ -62,6 +63,10 @@ describe 'ovn::controller' do
       is_expected.to contain_vs_config('external_ids:ovn-bridge').with(
         :value   => params[:ovn_bridge],
       )
+
+      is_expected.to contain_vs_config('external_ids:ovn-remote-probe-interval').with(
+        :value   => params[:ovn_remote_probe_interval],
+      )
     end
 
     it 'configures bridge mappings' do
